#!/bin/sh

# File: e17-menu-convert.sh
# by ^thehatsrule^ for testing with e17 on dsl
# to integrate fluxbox's menu entries into the e17 menu

# To use, just execute this script
# To override existing files, use the -f option

_MENU="${HOME}/.fluxbox/menu"
INSTALL_DIR="${HOME}/.e/e/applications/menu/favorite/dsl-menu"
if ! [ -e "${INSTALL_DIR}" ]; then
  printf "Creating ${INSTALL_DIR} ...\n"
  mkdir -p "${INSTALL_DIR}"
fi
if ! [ -d "${INSTALL_DIR}" ]; then
  printf "Error on using ${INSTALL_DIR}\n"
  exit 1
fi

cd "${INSTALL_DIR}"

IFS="
"

# optional icon stuff
_DISABLE_EXTRA_ICON=1
if [ -z "${_DISABLE_EXTRA_ICON}" ]; then
  XTDESKTOP_ICON_LIST=`ls ${HOME}/.xtdesktop/*.png`
fi

printf "Using: ${_MENU}\n"

for eachline in `cat ${_MENU}`
do
  _TITLE=`printf "${eachline}" | sed -e 's/.*\] *(//' -e 's/) *{.*//' -e 's!/!|!g' -e 's/\\\)/)/' `
#  _CMD=`printf "${eachline}" | sed -e 's/.*{//' -e 's/}.*//' `

  case "${eachline}" in
      *exec* )
          _Type="Application"
          _Name="${_TITLE}"
          _Exec=`printf "${eachline}" | sed -e 's/.*) *{//' -e 's/}.*//' `

          # optional icon stuff
          if [ -e "${HOME}/.xtdesktop/${_Name}.png" ]; then
            _Icon="${HOME}/.xtdesktop/${_Name}.png"
          else
            if [ -z "${_DISABLE_EXTRA_ICON}" ]; then
              # replace&add more complex icon scripts here in the future
              # but for now we don't care since this is disabled
              _Icon=`printf "${XTDESKTOP_ICON_LIST}" | grep -i "${_Name}" `
            fi
          fi

          _fname="${_Name}.desktop"
          printf "     "

          if [ "$1" = "-f" -o ! -e "${_fname}" ]; then
             printf "[Desktop Entry]\n" > ${_fname}
             printf "Type=${_Type}\n" >> ${_fname}
             printf "Exec=${_Exec}\n" >> ${_fname}
             printf "Name=${_Name}\n" >> ${_fname}
             if [ -n "${_Icon}" ]; then
               printf "Icon=${_Icon}\n" >> ${_fname}
             fi
             printf "${_Name}.desktop\n" 
          else
             printf "Skipping, ${_Name}.desktop already exists\n" 
          fi

          unset _Type _Name _Exec _Icon
          ;;
      *submenu* )
          if ! [ -d "${_TITLE}" ]; then
              mkdir "${_TITLE}"
          fi
          pushd "${_TITLE}" >/dev/null
          printf " -> ${_TITLE}\n"
          ;;
      *end* )
          popd >/dev/null 2>&1
          printf " <-\n"
          ;;
  esac

done
